clear; 
clc

%parameters
ta=23.00000; % hatching rate 
dy=1.46000; % Nymph mortality rate
de=0.36500; % Egg mortality rate
l=474.50000;  % lambda: per female egg production 
del_d= 0.1; % host mortality rate
del_b= 0.56200; % adult vector mortality rate
gy=1.7299; % Nymph maturation rate
u= 0.95; %phi 

rho = 0.01; % (TO BE VARIED) movement rate from salvative to peridomestic
tau = 0.01; % (TO BE VARIED) movement rate from peridomestic to salvatic

ih = 0.25; % dog infection prevalence
ib = 0.564; % bug infection prevalence

iw = 0.25; % wildlife infection prevalence
ibw = 0.564; % bug infection prevalence in salvatic cycle

epsilon = 0.25; % relative summer nymph molt rate 

Nh= 1000; % total host population
Nb(1)= 31600; % vector density

Nw= 1000; % total wildlife host population
Nbw(1)= 31600; % vector density in salvatic cycle

k=Nb*l*ta*(del_b+dy)/(gy*ta*l-del_b*(ta+de)*(gy+dy)); %carrying capacity at equilibrium
kw=Nbw*l*ta*(del_b+dy)/(gy*ta*l-del_b*(ta+de)*(gy+dy)); 

Ih(1)= ih*Nh; % infected host 
Sh(1)= Nh-Ih(1);  % Susciptible host  
E(1)=l*Nb(1)/(ta+de);  % Egg stage 
Y(1)=l*ta*Nb(1)*(k-Nb(1))/(l*ta*Nb(1)+k*(ta+de)*(dy+gy));    % Nyphm  
Ib1(1)= ib*Nb(1); % infected vector
Sb2(1)=(1-u)*gy*Y(1)/del_b;  % population not feeding on host under study
Sb1(1)=Nb(1)-Ib1(1)-Sb2(1); %Susceptible vector 
Nb1(1)= Ib1(1)+Sb1(1); % population of adult vector feeding on host

Iw(1)= iw*Nw; % infected host 
Sw(1)= Nw-Iw(1);  % Susciptible host  
Ew(1)=l*Nbw(1)/(ta+de);  % Egg stage 
Yw(1)=l*ta*Nbw(1)*(kw-Nbw(1))/(l*ta*Nbw(1)+kw*(ta+de)*(dy+gy));    % Nyphm  
Ibw(1)= ibw*Nbw(1); % infected vector
Sbw(1)=Nbw(1)-Ibw(1); %Susceptible vector 

Bv=del_b*Ib1(1)/(ih*Sb1(1)); % vector transmission rate
Bh=del_d*Ih(1)/(Sh(1)*Ib1(1)/Nb1(1)); % max host  transmission rate

Bvw=del_b*Ibw(1)/(iw*Sbw(1)); % vector transmission rate
Bhw=del_d*Iw(1)/(Sw(1)*Ibw(1)/Nbw(1)); % max host  transmission rate

% Cumulative incidence 
IncD(1)=0;
IncB(1)=0;

dt=1/5200;
T=0:dt:100; % years

for idx= 1:length(T)-1
    gyT=gy*FGamma(idx,dt,epsilon);
    BvT=Bv*FBeta(idx,dt);
    BhT=Bh*FBeta(idx,dt);
    BvwT=Bvw*FBeta(idx,dt);
    BhwT=Bhw*FBeta(idx,dt);
    rhoT=rho*FDispersal(idx,dt);
    tauT=tau*FDispersal(idx,dt);
    E(idx +1)= E(idx)+dt*(l*Nb(idx)-ta*E(idx)-de*E(idx)); % Egg Stage
    Y(idx+1)= Y(idx) + dt*(ta*E(idx)*(1-(Y(idx)+(Nb(idx)))/(k))-gyT*Y(idx)-dy*Y(idx)); % Nymph Stage
    Sb1(idx+1)= Sb1(idx)+ dt*(u*gyT*Y(idx)-BvT*Sb1(idx)*Ih(idx)/(Nh)-del_b*Sb1(idx)-tauT*Sb1(idx)+rhoT*u*Sbw(idx)); % Adult susceptible class
    Ib1(idx+1)= Ib1(idx)+ dt*(BvT*Sb1(idx)*Ih(idx)/(Nh)-del_b*Ib1(idx)-tauT*Ib1(idx)+rhoT*Ibw(idx)); % Adult Infected class
    Sb2(idx+1)= Sb2(idx) +dt*((1-u)*gyT*Y(idx)-del_b*Sb2(idx)-tauT*Sb2(idx)+rhoT*(1-u)*Sbw(idx));
    Sh(idx +1)= Sh(idx) +dt*(del_d*(Sh(idx)+Ih(idx))-BhT*Sh(idx)*Ib1(idx)/(Sb1(idx)+Ib1(idx))-del_d*Sh(idx)); % added and could be removed
    Ih(idx+1)= Ih(idx)+ dt*(BhT*Sh(idx)*Ib1(idx)/(Sb1(idx)+Ib1(idx))-del_d*Ih(idx)); % Infected host
    Nb(idx+1)=Sb1(idx)+Ib1(idx)+Sb2(idx);
    Nb1(idx+1)=Sb1(idx)+Ib1(idx);
    IncB(idx+1)= IncB(idx)+dt*((BvT*Sb1(idx)*Ih(idx)/(Nh))/(Nb(idx)));
    IncD(idx+1)= IncD(idx)+dt*((BhT*Sh(idx)*(Ib1(idx))/(Sb1(idx)+Ib1(idx)))/Nh);
    
    Ew(idx +1)= Ew(idx)+dt*(l*Nbw(idx)-ta*Ew(idx)-de*Ew(idx)); % Egg Stage
    Yw(idx+1)= Yw(idx) + dt*(ta*Ew(idx)*(1-(Yw(idx)+(Nbw(idx)))/(k))-gyT*Yw(idx)-dy*Yw(idx)); % Nymph Stage
    Sbw(idx+1)= Sbw(idx)+ dt*(gyT*Yw(idx)-BvwT*Sbw(idx)*Iw(idx)/(Nw)-del_b*Sbw(idx)+tauT*(Sb1(idx)+Sb2(idx))-rhoT*Sbw(idx)); % Adult susceptible class
    Ibw(idx+1)= Ibw(idx)+ dt*(BvwT*Sbw(idx)*Iw(idx)/(Nh)-del_b*Ibw(idx)+tauT*Ib1(idx)-rhoT*Ibw(idx)); % Adult Infected class
    Sw(idx +1)= Sw(idx) +dt*(del_d*(Sw(idx)+Iw(idx))-BhwT*Sw(idx)*Ibw(idx)/(Sbw(idx)+Ibw(idx))-del_d*Sw(idx)); % added and could be removed
    Iw(idx+1)= Iw(idx)+ dt*(BhwT*Sw(idx)*Ibw(idx)/(Sbw(idx)+Ibw(idx))-del_d*Iw(idx)); % Infected host
    Nbw(idx+1)=Sbw(idx)+Ibw(idx);
end

figure
subplot(2,1,1)
plot(T,Sb1,T,Ib1,'LineWidth',1.6)
grid on;
xlabel('yrs');
ylabel('Kissing bug population density');
legend('Sb1','Ib1');
title('the state variables');
subplot(2,1,2)
plot(T,Sbw,T,Ibw,'LineWidth',1.6)
grid on;
xlabel('yrs');
ylabel('Kissing bug population density');
legend('Sbw','Ibw');
title('the state variables');

figure
subplot(2,1,1)
plot(T,Sh,T,Ih,'LineWidth',1.6)
xlabel('yrs');
ylabel('Dog population');
legend('Sh','Ih');
subplot(2,1,2)
plot(T,Sw,T,Iw,'LineWidth',1.6)
xlabel('yrs');
ylabel('Wildlife population');
legend('Sw','Iw');


T1 = 100:dt:150; %ten year treatment 


%These variable are related to treatment
Pd = 0.3082; % (0.0761) prob of bug infection per bite https://europepmc.org/article/med/8702018

Tr= [3 6 9 12];% Treatment ferquencies in months, and days to death

for i=1:4
Tf = Tr(i);
dT = 365; % Drug induced death rate on bugs 

% variables keep track of bugs who feed on treated dogs
TSb1(1:length(T)-1)=0;
TIb1(1:length(T)-1)=0;


for idx= length(T)-1:length(T)+length(T1)-2
    gyT=gy*FGamma(idx,dt,epsilon);
    BvT=Bv*FBeta(idx,dt);
    BhT=Bh*FBeta(idx,dt);
    Tepsi = BvT/Pd;
    BvwT=Bvw*FBeta(idx,dt);
    BhwT=Bhw*FBeta(idx,dt);
    rhoT=rho*FDispersal(idx,dt);
    tauT=tau*FDispersal(idx,dt);
  
    E(idx+1)= E(idx)+dt*(l*Nb(idx)-ta*E(idx)-de*E(idx)); % Egg Stage
    Y(idx+1)= Y(idx) + dt*(ta*E(idx)*(1-(Y(idx)+(Nb(idx)))/(k))-gyT*Y(idx)-dy*Y(idx)); % Nymph Stage
    Sb1(idx+1)= Sb1(idx)+ dt*(u*gyT*Y(idx)-BvT*Sb1(idx)*Ih(idx)/(Nh)-del_b*Sb1(idx)-Tepsi*FTreat(idx,dt,Tf)*Sb1(idx)*(Sh(idx)+(1-Pd)*Ih(idx))*(1/Nh)-tauT*Sb1(idx)+rhoT*u*Sbw(idx)); % Adult susceptible class
    Ib1(idx+1)= Ib1(idx)+ dt*((1-FTreat(idx,dt,Tf))*BvT*Sb1(idx)*Ih(idx)/(Nh)-del_b*Ib1(idx)-Tepsi*FTreat(idx,dt,Tf)*Ib1(idx)-tauT*Ib1(idx)+rhoT*Ibw(idx)); % Adult Infected class
    TSb1(idx+1)=TSb1(idx)+dt*(Tepsi*FTreat(idx,dt,Tf)*Sb1(idx)*(Sh(idx)+(1-Pd)*Ih(idx))*(1/Nh)-BvT*TSb1(idx)*Ih(idx)/(Nh)-dT*(1/Fdeath(idx,dt,Tf))*TSb1(idx)-del_b*TSb1(idx));% Drug intoxicated adult susceptible
    TIb1(idx+1)=TIb1(idx)+dt*(FTreat(idx,dt,Tf)*BvT*Sb1(idx)*Ih(idx)/(Nh)+Tepsi*FTreat(idx,dt,Tf)*Ib1(idx)+BvT*TSb1(idx)*Ih(idx)/(Nh)-dT*(1/Fdeath(idx,dt,Tf))*TIb1(idx)-del_b*TIb1(idx));% Drug intoxicated adult infected
    Sb2(idx+1)= Sb2(idx) +dt*((1-u)*gyT*Y(idx)-del_b*Sb2(idx)-tauT*Sb2(idx)+rhoT*(1-u)*Sbw(idx));
    Sh(idx+1)= Sh(idx) +dt*(del_d*(Sh(idx)+Ih(idx))-BhT*Sh(idx)*(Ib1(idx)+TIb1(idx))/(Sb1(idx)+Ib1(idx)+TSb1(idx)+TIb1(idx))-del_d*Sh(idx)); % added and could be removed
    Ih(idx+1)= Ih(idx)+ dt*(BhT*Sh(idx)*(Ib1(idx)+TIb1(idx))/(Sb1(idx)+Ib1(idx)+TSb1(idx)+TIb1(idx))-del_d*Ih(idx)); % Infected host
    Nb(idx+1)=Sb1(idx)+Ib1(idx)+TSb1(idx)+TIb1(idx)+Sb2(idx);
    Nb1(idx+1)=Sb1(idx)+Ib1(idx)+TSb1(idx)+TIb1(idx);
    IncB(idx+1)= IncB(idx)+dt*((BvT*Sb1(idx)*Ih(idx)/(Nh)+BvT*TSb1(idx)*Ih(idx)/(Nh))/Nb(idx));
    IncD(idx+1)= IncD(idx)+dt*((BhT*Sh(idx)*(Ib1(idx)+TIb1(idx))/(Sb1(idx)+Ib1(idx)+TSb1(idx)+TIb1(idx)))/Nh);
    
    Ew(idx+1)= Ew(idx)+dt*(l*Nbw(idx)-ta*Ew(idx)-de*Ew(idx)); % Egg Stage
    Yw(idx+1)= Yw(idx) + dt*(ta*Ew(idx)*(1-(Yw(idx)+(Nbw(idx)))/(k))-gyT*Yw(idx)-dy*Yw(idx)); % Nymph Stage
    Sbw(idx+1)= Sbw(idx)+ dt*(gyT*Yw(idx)-BvwT*Sbw(idx)*Iw(idx)/(Nw)-del_b*Sbw(idx)+tauT*(Sb1(idx)+Sb2(idx))-rhoT*Sbw(idx)); % Adult susceptible class
    Ibw(idx+1)= Ibw(idx)+ dt*(BvwT*Sbw(idx)*Iw(idx)/(Nh)-del_b*Ibw(idx)+tauT*Ib1(idx)-rhoT*Ibw(idx)); % Adult Infected class
    Sw(idx+1)= Sw(idx) +dt*(del_d*(Sw(idx)+Iw(idx))-BhwT*Sw(idx)*Ibw(idx)/(Sbw(idx)+Ibw(idx))-del_d*Sw(idx)); % added and could be removed
    Iw(idx+1)= Iw(idx)+ dt*(BhwT*Sw(idx)*Ibw(idx)/(Sbw(idx)+Ibw(idx))-del_d*Iw(idx)); % Infected host
    Nbw(idx+1)=Sbw(idx)+Ibw(idx);
end

T2=[-2:dt:T1(end)-T1(1)]; % -1 is used to show the dynamics 2 years prior to treatment start
lT2=length(T2)-1;

InfBug = (Ib1(end-lT2:end)+TIb1(end-lT2:end))./(Ib1(end-lT2-lT2:end-lT2)+TIb1(end-lT2-lT2:end-lT2));
Rdens = (Sb1(end-lT2:end)+TSb1(end-lT2:end)+(Ib1(end-lT2:end)+TIb1(end-lT2:end)))./Nb1(end-lT2-lT2:end-lT2);
ARdens= movmean(Sb1(end-lT2:end)+TSb1(end-lT2:end)+(Ib1(end-lT2:end)+TIb1(end-lT2:end)),floor(1/dt))./movmean(Nb1(end-lT2-lT2:end-lT2),floor(1/dt));
subplot(2,4,i)
plot(T2,InfBug,'r',T2,Rdens,'b',T2,ARdens,'k','LineWidth',1.6)
%xlabel('year');
ylabel('Relative density');
legend('Infected bugs','Susceptible and infected bugs', 'Annual mean');
title([num2str(Tf),'-month regimen']);

% compute annual incidence per 1000 from cumulative incidence
ID(i,:) = (IncD(end-lT2:1/dt:end)*1000);
IB(i,:) = (IncB(end-lT2:1/dt:end)*1000);

subplot(2,4,4+i)
plot(T2,Ih(end-lT2:end)/Nh,'r',[-1:T1(end)-T1(1)],((ID(i,2)-ID(i,1))-(ID(i,2:end)-ID(i,1:end-1)))./(ID(i,2)-ID(i,1)),'--b','LineWidth',1.6)
xlabel('year of treatment');
ylabel('Proportion');
legend('Dog prevalence','Reduction dog incidence');
%title('Dog population');


% subplot(3,4,i)
% plot(T2,(Ib1(end-lT2:end)+TIb1(end-lT2:end))./(Ib1(end-lT2-lT2:end-lT2)+TIb1(end-lT2-lT2:end-lT2)),'r',T2,(Sb1(end-lT2:end)+TSb1(end-lT2:end)+(Ib1(end-lT2:end)+TIb1(end-lT2:end)))./Nb1(end-lT2-lT2:end-lT2),'b','LineWidth',1.6)
% grid on;
% %xlabel('year');
% ylabel('Relative density');
% legend('Infected bugs','Bugs');
% title([num2str(Tf),'-month regimen']);
% 
% subplot(3,4,4+i)
% plot(T2,Ih(end-lT2:end)/Nh,'LineWidth',1.6)
% %xlabel('year');
% ylabel('Dog prevalence');
% %legend('Infected dogs');
% %title('Dog population');
% 
% % compute annual incidence per 1000 from cumulative incidence
% ID(i,:) = (IncD(end-lT2:1/dt:end)*1000);
% IB(i,:) = (IncB(end-lT2:1/dt:end)*1000);
% 
% subplot(3,4,4*2+i)
% plot([-1:T1(end)-T1(1)],100*((ID(i,2)-ID(i,1))-(ID(i,2:end)-ID(i,1:end-1)))./(ID(i,2)-ID(i,1)),[-1:T1(end)-T1(1)],100*((IB(i,2)-IB(i,1))-(IB(i,2:end)-IB(i,1:end-1)))./(IB(i,2)-IB(i,1)),'LineWidth',1.6)
% xlabel('year of treatment');
% ylabel('Reduction of annual incidence (%)');
% legend('Dog','Bug');
end

figure
subplot(2,1,1)
plot([-2:length(ID(1,:))-3],ID(4,:)-ID(1,:),[-2:length(ID(1,:))-3],ID(4,:)-ID(2,:),[-2:length(ID(1,:))-3],ID(4,:)-ID(3,:),'LineWidth',1.6)
title('Dog infections averted relative to 12-month regimen')
ylabel('Relative infections averted per 1000')
legend('3-month','6-month','9-month');
subplot(2,1,2)
plot([-2:length(IB(1,:))-3],IB(4,:)-IB(1,:),[-2:length(IB(1,:))-3],IB(4,:)-IB(2,:),[-2:length(IB(1,:))-3],IB(4,:)-IB(3,:),'LineWidth',1.6)
xlabel('Duration of intervention (years)')
ylabel('Relative infections averted per 1000')
legend('3-month','6-month','9-month');
title('Bug infections averted relative to 12-month regimen')
